@@ -1,11 +1,11 @@
 import time
-import requests
 import asyncio
+
+import requests
 import aiohttp
 
-from .config import create_task_url, app_key
-from .errors import ParamError, ReadError, IdGetError
-from .get_answer import get_sync_result, get_async_result
+from python3_anticaptcha import create_task_url, app_key, get_sync_result, get_async_result, \
+                                ParamError, ReadError, IdGetError
 
 
 class NoCaptchaTask:
