@@ -1,14 +1,14 @@
-import requests
 import time
-import aiohttp
 import asyncio
 import hashlib
 import os
 import base64
 
-from .config import create_task_url, app_key
-from .errors import ParamError, ReadError, IdGetError
-from .get_answer import get_sync_result, get_async_result
+import requests
+import aiohttp
+
+from python3_anticaptcha import create_task_url, app_key, get_sync_result, get_async_result, \
+                                ParamError, ReadError, IdGetError
 
 
 class SquareNetTextTask:
